@@ -1,9 +1,8 @@
 use strict;
 use warnings;
 package Child;
-our $VERSION = '0.100770';
 use Godfather;
-use base qw(Parent Godfather);
+use base qw(Mother Godfather);
 1;
 __DATA__
 __[b]__
